use std::collections::HashMap;

use serde::Deserialize;

use crate::spotify_auth::Token;
use crate::spotify_types::*;

#[derive(Deserialize, Debug)]
pub struct TopSongsResponse {
    pub href: String,
    pub limit: u32, // Default is 20, we don't change this.
    pub next: Option<String>,
    pub offset: u32,
    pub previous: Option<String>,
    pub total: u32,
    pub items: Vec<TrackObject>, // There should be 20 of these, not guaranteed
}

pub async fn get_top_tracks(token: &Token) -> Result<TopSongsResponse, reqwest::Error> {
    let mut params = HashMap::new();
    params.insert("time_range", "short_term");

    let client = reqwest::Client::new();
    let res: TopSongsResponse = client
        .get(crate::BASE_URL.to_owned() + "/me/top/tracks")
        .query(&params)
        .header("Authorization", "Bearer ".to_owned() + &token.0)
        .send()
        .await?
        .json()
        .await?;

    Ok(res)
}
