use serde::{Deserialize};
use std::collections::HashMap;

use crate::spotify_auth::Token;
use crate::{spotify_types::*, BASE_URL};

pub async fn get_tracks(
    token: &Token,
    tracks: &[&Uri],
) -> Result<Vec<TrackObject>, reqwest::Error> {
    let pieces = tracks.chunks(50);

    let mut out = Vec::<TrackObject>::new();
    for piece in pieces {
        out.append(&mut get_tracks_helper(token, piece).await?)
    }

    Ok(out)
}

#[derive(Debug, Deserialize)]
pub struct TracksResult {
    pub tracks: Vec<TrackObject>,
}

// We can only get 50 at a time!
async fn get_tracks_helper(
    token: &Token,
    tracks: &[&Uri],
) -> Result<Vec<TrackObject>, reqwest::Error> {
    let mut params: HashMap<&str, String> = HashMap::new();
    let tracks_str: String = tracks
        .iter()
        .map(|uri| uri.get_suffix())
        .collect::<Vec<String>>()
        .join(",");
    params.insert("ids", tracks_str);

    let client = reqwest::Client::new();
    let res = client
        .get(BASE_URL.to_owned() + "/tracks")
        .query(&params)
        .bearer_auth(token.0.clone())
        .send()
        .await?
        .json::<TracksResult>()
        .await?
        .tracks;

    Ok(res)
}
